==> haskell-ghc-syb-utils-0.2.3.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-syb-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-syb-utils
version: 0.2.3.2
id: ghc-syb-utils-0.2.3.2-IPEs1Lr2M4bGRu49XAswac
key: ghc-syb-utils-0.2.3.2-IPEs1Lr2M4bGRu49XAswac
license: BSD3
copyright: (c) Claus Reinke 2008
maintainer: Thomas Schilling <nominolo@googlemail.com>
stability: provisional
homepage: http://github.com/nominolo/ghc-syb
synopsis: Scrap Your Boilerplate utilities for the GHC API.
description:
    Scrap Your Boilerplate utilities for the GHC API.
category: Development
author: Claus Reinke
exposed: True
indefinite: False
exposed-modules:
    GHC.SYB.Utils
abi: 8ba98bdbca76b399ef19a0066a17d9b7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ghc-syb-utils-0.2.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/ghc-syb-utils-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/ghc-syb-utils-0.2.3.2
hs-libraries: HSghc-syb-utils-0.2.3.2-IPEs1Lr2M4bGRu49XAswac
depends:
    base-4.10.0.0 syb-0.7-2rRPTNxBP6YFePrCXw4i2o ghc-8.2.1
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=4ce6cc08831568c116a562974ba627d9
             ghc-8.2.1=d6794b22e3c84774d2039c678f806d00
haddock-interfaces: /usr/share/doc/haskell-ghc-syb-utils/html/ghc-syb-utils.haddock
haddock-html: /usr/share/doc/haskell-ghc-syb-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-syb-utils-0.2.3.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-syb-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-syb-utils
version: 0.2.3.3
id: ghc-syb-utils-0.2.3.3-5vZRqCuYEy4CNX41zfUVUC
key: ghc-syb-utils-0.2.3.3-5vZRqCuYEy4CNX41zfUVUC
license: BSD3
copyright: (c) Claus Reinke 2008
maintainer: Thomas Schilling <nominolo@googlemail.com>
stability: provisional
homepage: http://github.com/nominolo/ghc-syb
synopsis: Scrap Your Boilerplate utilities for the GHC API.
description:
    Scrap Your Boilerplate utilities for the GHC API.
category: Development
author: Claus Reinke
exposed: True
indefinite: False
exposed-modules:
    GHC.SYB.Utils
abi: 7ae5cf85f717e64eb005d23c1458084d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ghc-syb-utils-0.2.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/ghc-syb-utils-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/ghc-syb-utils-0.2.3.3
hs-libraries: HSghc-syb-utils-0.2.3.3-5vZRqCuYEy4CNX41zfUVUC
depends:
    base-4.10.0.0 syb-0.7-2rRPTNxBP6YFePrCXw4i2o ghc-8.2.1
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=4ce6cc08831568c116a562974ba627d9
             ghc-8.2.1=4285bd5e3c4b90d109a0b9ef857e45e9
haddock-interfaces: /usr/share/doc/haskell-ghc-syb-utils/html/ghc-syb-utils.haddock
haddock-html: /usr/share/doc/haskell-ghc-syb-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
